@@ -3,7 +3,7 @@
 import matplotlib.pyplot as plt
 
 import geomstats.backend as gs
-from geomstats.geometry.hyperbolic import Hyperbolic
+from geomstats.geometry.hyperboloid import Hyperboloid
 from geomstats.geometry.hypersphere import Hypersphere
 from geomstats.geometry.special_euclidean import SpecialEuclidean
 from geomstats.geometry.special_orthogonal import SpecialOrthogonal
@@ -11,9 +11,9 @@ from mpl_toolkits.mplot3d import Axes3D  # NOQA
 
 SE3_GROUP = SpecialEuclidean(n=3)
 SO3_GROUP = SpecialOrthogonal(n=3)
-S1 = Hypersphere(dimension=1)
-S2 = Hypersphere(dimension=2)
-H2 = Hyperbolic(dimension=2)
+S1 = Hypersphere(dim=1)
+S2 = Hypersphere(dim=2)
+H2 = Hyperboloid(dim=2)
 
 AX_SCALE = 1.2
 
@@ -98,8 +98,6 @@ class Circle():
     def draw_points(self, ax, points=None, **plot_kwargs):
         if points is None:
             points = self.points
-        else:
-            points = points
         points = gs.array(points)
         ax.plot(points[:, 0], points[:, 1], marker='o', linestyle="None",
                 **plot_kwargs)
@@ -161,8 +159,6 @@ class Sphere():
     def draw_points(self, ax, points=None, **scatter_kwargs):
         if points is None:
             points = self.points
-        else:
-            points = points
         points_x = gs.vstack([point[0] for point in points])
         points_y = gs.vstack([point[1] for point in points])
         points_z = gs.vstack([point[2] for point in points])
@@ -239,7 +235,11 @@ class PoincareDisk():
 
         if not isinstance(points, list):
             points = points.tolist()
-        self.points.extend(points)
+
+        if gs.all([len(point) == 2 for point in self.points]):
+            self.points.extend(points)
+        else:
+            raise ValueError('Points do not have dimension 2.')
 
     def convert_to_poincare_coordinates(self, points):
         poincare_coords = points[:, 1:] / (1 + points[:, :1])
@@ -248,9 +248,15 @@ class PoincareDisk():
     def draw(self, ax, **kwargs):
         circle = plt.Circle((0, 0), radius=1., color='black', fill=False)
         ax.add_artist(circle)
-        points_x = gs.vstack([point[0] for point in self.points])
-        points_y = gs.vstack([point[1] for point in self.points])
-        ax.scatter(points_x, points_y, **kwargs)
+        if len(self.points) > 0:
+            if gs.all([len(point) == 2 for point in self.points]):
+                points_x = gs.stack(
+                    [point[0] for point in self.points], axis=0)
+                points_y = gs.stack(
+                    [point[1] for point in self.points], axis=0)
+                ax.scatter(points_x, points_y, **kwargs)
+            else:
+                raise ValueError('Points do not have dimension 2.')
 
 
 class PoincarePolyDisk():
@@ -404,7 +410,7 @@ def convert_to_trihedron(point, space=None):
     point = gs.to_ndarray(point, to_ndim=2)
     n_points, _ = point.shape
 
-    dim_rotations = SO3_GROUP.dimension
+    dim_rotations = SO3_GROUP.dim
 
     if space == 'SE3_GROUP':
         rot_vec = point[:, :dim_rotations]
