@@ -29,6 +29,7 @@ r_z = gs.array([
     [1., 0., 0.],
     [0., 0., 0.]])
 pi_2 = gs.pi / 2
+pi_4 = gs.pi / 4
 
 
 class TestGrassmannianMethods(geomstats.tests.TestCase):
@@ -53,3 +54,20 @@ class TestGrassmannianMethods(geomstats.tests.TestCase):
             gs.array([p_xy, p_yz]))
         expected = gs.array([p_yz, p_xz])
         self.assertAllClose(result, expected)
+
+    @geomstats.tests.np_only
+    def test_log(self):
+        result = self.metric.log(
+            self.metric.exp(pi_4 * r_y, p_xy),
+            p_xy)
+        expected = pi_4 * r_y
+        self.assertAllClose(result, expected)
+
+    @geomstats.tests.np_only
+    def test_log_vectorized(self):
+        tangent_vecs = pi_4 * gs.array([r_y, r_z])
+        base_points = gs.array([p_xy, p_xz])
+        points = self.metric.exp(tangent_vecs, base_points)
+        result = self.metric.log(points, base_points)
+        expected = tangent_vecs
+        self.assertAllClose(result, expected)
